# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-05 16:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djxami', '0003_message_stream'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='expires',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='message',
            name='permanent',
            field=models.BooleanField(default=False),
        ),
    ]
