# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-04 17:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djxami', '0002_auto_20160204_1556'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='stream',
            field=models.BooleanField(default=False),
        ),
    ]
