# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-02-04 14:43
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import jsonfield.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('djxami', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='NottyMessage',
            fields=[
                ('message_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='djxami.Message')),
                ('scripts', models.CharField(blank=True, max_length=500)),
                ('notty_options', jsonfield.fields.JSONField(blank=True, null=True)),
            ],
            bases=('djxami.message',),
        ),
    ]
