{% load static %}
<script src="{% static 'djxami/core.js' %}"></script>
<script src="{% static 'djnotty/js/jquery.noty.packaged.min.js' %}"></script>
<script src="{% static 'djnotty/js/djnotty.js' %}"></script>
<link rel="stylesheet" href="{% static 'djnotty/css/progressbar.css' %}">

<script>
    $.fn.djxami_core({
        'url': '{% url 'djxami:messages' %}',
        'mars_read_url': '{% url 'djxami:close' %}',
        'stream_url': '{% url 'djxami:stream' %}',
        'csrf_token': '{{ csrf_token }}',
        'first_query_pause': '{{ first_query_pause  }}',
        'queries_interval': '{{ queries_interval }}',
        'stream_interval': '{{ stream_interval }}',
    })

</script>